@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_ec2._jsii
 import aws_cdk.aws_iam._jsii
@@ -17,7 +17,7 @@ import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-redshift", "1.61.1", __name__[0:-6], "aws-redshift@1.61.1.jsii.tgz"
+    "@aws-cdk/aws-redshift", "1.67.0", __name__[0:-6], "aws-redshift@1.67.0.jsii.tgz"
 )
 
 __all__ = [
